<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2015 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\CDev\Paypal\Controller\Customer;

use \XLite\Module\CDev\Paypal;

/**
 * Checkout controller
 */
class Callback extends \XLite\Controller\Customer\Callback implements \XLite\Base\IDecorator
{
    protected $ignore = false;

    /**
     * @var \XLite\Model\Payment\Transaction
     */
    protected $transaction;

    /**
     * Process callback
     */
    protected function doActionCallback()
    {
        $this->detectTransaction();

        if (!$this->ignore) {
            parent::doActionCallback();
            if ($this->transaction && $this->transaction->isByPayPal()) {
                Paypal\Core\Lock\OrderLocker::getInstance()->unlock($this->transaction->getOrder());
            }
        }
    }

    /**
     * Detect transaction from request or from the inner payment methods detection
     *
     * @return \XLite\Model\Payment\Transaction
     */
    protected function detectTransaction()
    {
        if (null === $this->transaction) {
            $this->transaction = parent::detectTransaction();
            if ($this->transaction && $this->transaction->isByPayPal()) {
                $order = $this->transaction->getOrder();
                if (Paypal\Core\Lock\OrderLocker::getInstance()->isLocked($order)) {
                    $this->ignore = true;

                } else {
                    Paypal\Core\Lock\OrderLocker::getInstance()->lock($order);
                }
            }
        }

        return $this->transaction;
    }
}
