<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2015 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\CDev\Paypal\Core\Lock;

use XLite\Module\CDev\Paypal;

/**
 * Order locker
 */
class OrderLocker extends \XLite\Core\Lock\AObjectCacheLocker
{
    /**
     * Lock object
     *
     * @param Object       $object Object
     * @param integer|null $ttl    TTL OPTIONAL
     */
    public function lock($object, $ttl = null)
    {
        parent::lock($object, $ttl);
        Paypal\Main::addLog('Lock order', array('OrderId' => $object->getOrderId()));
    }

    /**
     * Unlock object
     *
     * @param Object $object Object
     */
    public function unlock($object)
    {
        parent::unlock($object);
        Paypal\Main::addLog('Unlock order', array('OrderId' => $object->getOrderId()));
    }

    /**
     * Check locked state
     *
     * @param Object       $object Object
     * @param boolean      $strict Do not check for expiration OPTIONAL
     * @param integer|null $ttl    Time to live in seconds OPTIONAL
     *
     * @return boolean
     */
    public function isLocked($object, $strict = false, $ttl = null)
    {
        $status = parent::isLocked($object, $strict, $ttl);
        Paypal\Main::addLog(
            'Check order lock state',
            array(
                'OrderId' => $object->getOrderId(),
                'status' => $status ? 'locked' : 'unlocked',
            )
        );

        return $status;
    }

    /**
     * @param \XLite\Model\Order $object Order entity
     *
     * @return string
     */
    protected function getIdentifier($object)
    {
        return $object->getOrderId();
    }
}
