<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2013 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\Controller\Customer;

/**
 * Decorated Cart controller.
 */
abstract class Cart extends \XLite\Controller\Customer\Cart implements \XLite\Base\IDecorator
{
    /**
     * Add order item to cart.
     * Additional correction of item amount is made before adding.
     *
     * @param \XLite\Model\OrderItem $item Order item
     *
     * @return boolean
     */
    protected function addItem($item)
    {
        return $this->checkItemBeingAdded($item) && parent::addItem($item);
    }

    /**
     * Check if the item can be added to cart.
     *
     * @param \XLite\Model\OrderItem $item Item being added
     *
     * @return boolean
     */
    protected function checkItemBeingAdded(\XLite\Model\OrderItem $item)
    {
        return $item && !$this->isCallForPriceItem($item);
    }

    /**
     * Check if the item is a Call For Price product.
     *
     * @param \XLite\Model\OrderItem $item Order item
     *
     * @return boolean
     */
    protected function isCallForPriceItem(\XLite\Model\OrderItem $item)
    {
        return $item && $item->getProduct() && $item->getProduct()->isCallForPrice();
    }
} 
