<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2016 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\View\Button\Product;

/**
 * Decorated Express Checkout button.
 *
 * @LC_Dependencies ("CDev\Paypal", "XC\ProductVariants", "QSL\CallForPrice")
 */
class ExpressCheckoutWithVariants extends \XLite\Module\CDev\Paypal\View\Button\Product\ExpressCheckout
    implements \XLite\Base\IDecorator
{
    /**
     * Product variant
     *
     * @var mixed
     */
    protected $productVariant;

    /**
     * Return product variant
     *
     * @return mixed
     */
    protected function getProductVariant()
    {
        if (!isset($this->productVariant)) {
            if ($this->getProduct()->mustHaveVariants()) {
                $this->productVariant = $this->getProduct()->getVariant($this->getAttributeValues());
            }

            if (!$this->productVariant) {
                $this->productVariant = false;
            }
        }

        return $this->productVariant;
    }

    /**
     * Return product attributes array from the request parameters
     *
     * @return array
     */
    protected function getAttributeValues()
    {
        $ids = array();
        $attributeValues = trim(\XLite\Core\Request::getInstance()->{\XLite\View\Product\Details\Customer\Widget::PARAM_ATTRIBUTE_VALUES}, ',');

        if ($attributeValues) {
            $attributeValues = explode(',', $attributeValues);
            foreach ($attributeValues as $v) {
                $v = explode('_', $v);
                $ids[$v[0]] = $v[1];
            }
        }

        return $this->getProduct()->prepareAttributeValues($ids);
    }

    /**
     * Check if it is a Call For Price item.
     *
     * @return boolean
     */
    protected function isCallForPrice()
    {
        return parent::isCallForPrice()
            && (
                !$this->hasProductVariants()
                ||
                ($this->getProductVariant() && $this->getProductVariant()->isCallForPrice())
                ||
                // In product lists getProductVariant() may return a variant that is not Call For Price -> this will
                // result into FALSE, that is not right, so we do one more check
                !$this->isProductDetails()
            );
    }

    /**
     * Check if the product has variants.
     *
     * @return boolean
     */
    protected function hasProductVariants()
    {
        return $this->getProduct()->mustHaveVariants();
    }

    /**
     * Check if it is a product details widget (product page or quick look).
     *
     * @return boolean
     */
    protected function isProductDetails()
    {
        $target = \XLite\Core\Request::getInstance()->target;

        return ('product' == $target) || ('quick_look' == $target) || ('widgets_collection' == $target);
    }    
}