<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2013 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\View\Product\Details\Customer;

/**
 * Decorated product widget.
 *
 * @LC_Dependencies ("XC\ProductVariants", "QSL\CallForPrice")
 */
abstract class WidgetWithVariants extends \XLite\View\Product\Details\Customer\Widget implements \XLite\Base\IDecorator
{
    /**
     * Check if it is a Call For Price item.
     *
     * @return boolean
     */
    protected function isCallForPrice()
    {
        return parent::isCallForPrice()
            && (
                !$this->hasProductVariants()
                ||
                ($this->getProductVariant() && $this->getProductVariant()->isCallForPrice())
                ||
                // In product lists getProductVariant() may return a variant that is not Call For Price -> this will
                // result into FALSE, that is not right, so we do one more check
                !$this->isProductDetails()
            );
    }

    /**
     * Check if the product has variants.
     *
     * @return boolean
     */
    protected function hasProductVariants()
    {
        return $this->getProduct()->mustHaveVariants();
    }

    /**
     * Check if it is a product details widget (product page or quick look).
     *
     * @return boolean
     */
    protected function isProductDetails()
    {
        $target = \XLite\Core\Request::getInstance()->target;

        return ('product' == $target) || ('quick_look' == $target) || ('widgets_collection' == $target);
    }
} 