<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2013 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\Controller\Admin;

/**
 * Decorated controller for the product list.
 */
abstract class ProductList extends \XLite\Module\CDev\FeaturedProducts\Controller\Admin\ProductList implements \XLite\Base\IDecorator
{
    /**
     * Do action "Switch to Add to Cart".
     *
     * @return void
     */
    protected function doActionSwitchToCallForPrice()
    {
        $this->updateCallForPriceSetting(true);
    }

    /**
     * Do action "Switch to Add to Cart".
     *
     * @return void
     */
    protected function doActionSwitchToAddToCart()
    {
        $this->updateCallForPriceSetting(false);
    }


    /**
     * Update Call For Price setting for selected products.
     *
     * @param boolean $setting Whether to enable Call For Price setting for selected products, or disable.
     *
     * @return void
     */
    protected function updateCallForPriceSetting($setting)
    {
        $select = \XLite\Core\Request::getInstance()->select;

        if ($select && is_array($select)) {

            \XLite\Core\Database::getRepo('\XLite\Model\Product')
                ->updateInBatchById($this->getCallForPriceUpdateInfo($setting));

            \XLite\Core\TopMessage::addInfo(
                'Products information has been successfully updated'
            );

        } else {
            \XLite\Core\TopMessage::addWarning('Please select products first');
        }
    }

    /**
     * Prepare the update information for Call For Price setting.
     * 
     * @return array
     */
    protected function getCallForPriceUpdateInfo($setting)
    {
        return array_fill_keys(
            array_keys($this->getSelected()),
            array('callForPrice' => $setting, 'enabled' => true)
        );
    }

}
