<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 * 
 * -----------------------------------------------------------------------------
 * CHANGES
 * 
 * 5.2.5
 * - fixed the issue with PayPal Express Checkout buttons not being
 *   hidden (#0045800)
 * - fixed the issue with Add To Cart buttons not being removed from lists of
 *   products (#0045800)
 * - fixed the incompatibility with Hide Prices module
 * - fixed the issue with "Call For Price" message being too long and displayed
 *   in a wrong column in lists of products (in the "table" view mode)
 * 
 * ----------------------------------------------------------------------------- *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2016 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice;

/**
 * Main module
 */
abstract class Main extends \XLite\Module\AModule
{
    /**
     * Author name
     *
     * @return string
     */
    public static function getAuthorName()
    {
        return 'Qualiteam Software';
    }

    /**
     * Module name
     *
     * @return string
     */
    public static function getModuleName()
    {
        return 'Call For Price';
    }

    /**
     * Module description
     *
     * @return string
     */
    public static function getDescription()
    {
        return 'With this module you can hide price and "Add to cart" button for particular products and show a "Call For Price" message instead.';
    }

    /**
     * Get module major version
     *
     * @return string
     */
    public static function getMajorVersion()
    {
        return '5.2';
    }

    /**
     * Module version
     *
     * @return string
     */
    public static function getMinorVersion()
    {
        return '5';
    }

    /**
     * Determines if we need to show settings form link
     *
     * @return boolean
     */
    public static function showSettingsForm()
    {
        return true;
    }

    /**
     * Actions that take place after redeploying the store.
     *
     * @return void
     */
    public static function runBuildCacheHandler()
    {
        parent::runBuildCacheHandler();
        
        // Due to https://bt.x-cart.com/view.php?id=45778 we have to implement
        // the workaround that creates an intermediate view list.
        static::moveTemplates();
    }
    
    /**
     * Moves templates between view lists.
     * 
     * We have to imitate the AModule::manageWidgets() method because the
     * original one does not check if the specified template presents in the
     * initial view list actually. So, "moving" a non-existing template from
     * one list to another will create it in the new view list.
     * 
     * @return void
     */
    protected static function moveTemplates()
    {
        $data = array(
            '.qslcfpadd2cart' => array(
                'itemsList.product.table.customer.columns' => array(
                    // Only one from the list will be moved
                    array(
                        'items_list/product/parts/common.button-add2cart.tpl',
                        'modules/CDev/ProductAdvisor/items_list/product/parts/common.button-add2cart.tpl',
                        'modules/QSL/HidePrices/items_list/product/common.button-add2cart.tpl',
                    ),
                ),
                'itemsList.product.grid.customer.tail' => array(
                    array(
                        'items_list/product/parts/grid.button-add2cart-wrapper.tpl',
                    )
                ),
                'itemsList.product.list.customer.info' => array(
                    array(
                        'items_list/product/parts/list.button-add2cart.tpl',
                    ),
                    array(
                        'modules/CDev/Paypal/item_list/product/parts/express_checkout.tpl',
                    ),
                ),
            ),
            '.qslcfpprice' => array(
                'itemsList.product.table.customer.columns' => array(
                    array(
                        'items_list/product/parts/common.product-price.tpl',
                    ),
                ),
            ),
        );

        $layout = \XLite\Core\Layout::getInstance();
        foreach ($data as $suffix => $moves) {
            foreach ($moves as $list => $groups) {
                $tpls = array();
                foreach (\XLite\Core\Database::getRepo('\XLite\Model\ViewList')->findByList($list) as $tpl) {
                    $file = $tpl->getTpl();
                    $tpls[] = $file;
                }
                foreach ($groups as $search) {
                    $found = false;
                    while (!$found && !empty($search)) {
                        $file = array_pop($search);
                        $found = in_array($file, $tpls);
                        if ($found) {
                            $layout->removeTemplateFromList($file, $list);
                            $layout->addTemplateToList($file, $list . $suffix);
                        }
                    }
                }
            }
        }
        \XLite\Core\Database::getEM()->flush();
    }

}
