<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2016 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\View\Button\ProductList;

/**
 * Decorated Express Checkout button.
 *
 * @LC_Dependencies ("CDev\Paypal")
 */
abstract class ExpressCheckout extends \XLite\Module\CDev\Paypal\View\Button\ProductList\ExpressCheckoutAbstract
    implements \XLite\Base\IDecorator
{
    /**
     * Returns true if widget is visible
     *
     * @return boolean
     */
    protected function isVisible()
    {
        return parent::isVisible() && $this->isQSLCallForPriceVisible();
    }
    
    /**
     * Check if the button is still visible after Hide Prices checks.
     * 
     * @return boolean
     */
    protected function isQSLCallForPriceVisible()
    {
        return !$this->getProduct()->isCallForPrice();
    }
    
    /**
     * Returns the product model that the button is displayed for.
     * 
     * @return \XLite\Model\Product
     */
    protected function getProduct()
    {
        $id = $this->getParam(static::PARAM_PRODUCT_ID);
        
        return $id ? \XLite\Core\Database::getRepo('\XLite\Model\Product')->find($id) : null;
    }
}