<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2013 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\CallForPrice\View;

/**
 * Widget displaying the Call For Price section.
 */
class CallForPrice extends \XLite\View\Product\Details\Customer\Widget
{
    /**
     * Widget parameters
     */
    const PARAM_DETAILS = 'details';
    const PARAM_SHORT = 'short';

    /**
     * Return the specific widget service name to make it visible as specific CSS class
     *
     * @return null|string
     */
    public function getFingerprint()
    {
        return 'widget-fingerprint-product-call-for-price';
    }

    /**
     * Get a list of CSS files required to display the widget properly
     *
     * @return array
     */
    public function getCSSFiles()
    {
        $list = parent::getCSSFiles();

        $list[] = 'modules/QSL/CallForPrice/call_for_price/styles.css';

        return $list;
    }

    /**
     * Get CSS classes for the widget's "class" HTML attribute.
     *
     * @return string
     */
    protected function getCSSClass()
    {
        return 'call-for-price-text'
            . ($this->isProductDetails() ? ' call-for-price-product-text' : ' call-for-price-catalog-text')
            . ($this->isShortText() ? ' call-for-price-text-short' : ' call-for-price-text-full');
    }

    /**
     * Define widget parameters
     *
     * @return void
     */
    protected function defineWidgetParams()
    {
        parent::defineWidgetParams();

        $this->widgetParams += array(
            static::PARAM_DETAILS => new \XLite\Model\WidgetParam\Bool('Product details', true),
        );
        $this->widgetParams += array(
            static::PARAM_SHORT => new \XLite\Model\WidgetParam\Bool('Short text', false),
        );
    }

    /**
     * Check if the widget should be shown as empty (required for WidgetsCollection).
     *
     * @return boolean
     */
    protected function isWidgetEmpty()
    {
        return !$this->isCallForPrice() || (!$this->isProductDetails() && $this->getProduct()->mustHaveVariants());
    }

    /**
     * Return widget default template
     *
     * @return string
     */
    protected function getDefaultTemplate()
    {
        return 'modules/QSL/CallForPrice/call_for_price/body.tpl';
    }

    /**
     * Get Call For Price text.
     *
     * @return string
     */
    protected function getCallForPriceText()
    {
        $config = \XLite\Core\Config::getInstance();

        return $this->isShortText()
            ? $this->getShortText()
            : str_replace(
                '[COMPANY_PHONE]',
                $config->Company->company_phone,
                $this->isProductDetails() ? $config->QSL->CallForPrice->callforprice_product
                    : $config->QSL->CallForPrice->callforprice_catalog
            );
    }

    /**
     * Check if it is a product details widget (product page or quick look).
     *
     * @return boolean
     */
    protected function isProductDetails()
    {
        return $this->getParam(self::PARAM_DETAILS);
    }

    /**
     * Check if the text should be short.
     *
     * @return boolean
     */
    protected function isShortText()
    {
        return $this->getParam(self::PARAM_SHORT);
    }

    /**
     * Returns the short text.
     *
     * @return boolean
     */
    protected function getShortText()
    {
        return $this->t('Call For Price');
    }

    /**
     * Get Call For Price tooltip text.
     *
     * @return string
     */
    protected function getCallForPriceTooltip()
    {
        $config = \XLite\Core\Config::getInstance();

        return str_replace(
            '[COMPANY_PHONE]',
            $config->Company->company_phone,
            $config->QSL->CallForPrice->callforprice_tooltip
        );
    }

}